==> gm4_smelteries_1_21.zip: README.md <==
# <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="GM4 Logo" width="32" /> Smelteries by Gamemode 4

Build a multi-block structure to double the output of your ores!

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_smelteries/images/creating_smeltery.gif" alt="Creating a Smeltery, block by block." height="350"/>  

### Features
- Adds a 3x2x3 multi-block structure made of iron blocks, glass, a furnace and a cauldron
- Doubles Iron, Gold, Copper, Sand and Chorus Fruit
- Smelteries have a 1 in 90 chance of filling the Cauldron with Lava

### More Info
[<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_wiki_logo.png" alt="Gamemode 4 Wiki Logo" width="40" align="center"/> **Read the Wiki**](https://wiki.gm4.co/wiki/smelteries)

### Credits
- Creator: [Bloo](https://bsky.app/profile/bloo.boo)
- Updated By: [Andante](https://bsky.app/profile/andante.dev), [Kroppeb](https://tech.lgbt/@Kroppeb), [Misode](https://bsky.app/profile/misode.dev), [SpecialBuilder32](https://bsky.app/profile/specialbuilder32.bsky.social), [BPR](https://bsky.app/profile/bpr02.com)
- Textures By: [Kyrius](https://bsky.app/profile/kyriuspixels.bsky.social)
- Icon Design: Hozz

---
## About Gamemode 4 <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="Gamemode 4 Logo" width="20"/>
Gamemode 4 is a series of command-powered creations that are designed to change and enhance the survival experience. All of our modules are designed to work together flawlessly, and are balanced for usage in a survival setting. Pick and choose your favorites from our [website](https://gm4.co), or wherever you get datapacks.

==> gm4_smelteries_1_21_5.zip: README.md <==
# <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="GM4 Logo" width="32" /> Smelteries by Gamemode 4

Build a multi-block structure to double the output of your ores!

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_smelteries/images/creating_smeltery.gif" alt="Creating a Smeltery, block by block." height="350"/>  

### Features
- Adds a 3x2x3 multi-block structure made of iron blocks, glass, a furnace and a cauldron
- Doubles Iron, Gold, Copper, Sand and Chorus Fruit
- Smelteries have a 1 in 90 chance of filling the Cauldron with Lava

### More Info
[<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_wiki_logo.png" alt="Gamemode 4 Wiki Logo" width="40" align="center"/> **Read the Wiki**](https://wiki.gm4.co/wiki/smelteries)

### Credits
- Creator: [Bloo](https://bsky.app/profile/bloo.boo)
- Updated By: [dvitski](https://bsky.app/profile/dvitski.cc), [Kroppeb](https://tech.lgbt/@Kroppeb), [Misode](https://bsky.app/profile/misode.dev), [SpecialBuilder32](https://bsky.app/profile/specialbuilder32.bsky.social), [BPR](https://bsky.app/profile/bpr02.com)
- Textures By: [Kyrius](https://bsky.app/profile/kyriuspixels.bsky.social)
- Icon Design: Hozz

---
## About Gamemode 4 <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="Gamemode 4 Logo" width="20"/>
Gamemode 4 is a series of command-powered creations that are designed to change and enhance the survival experience. All of our modules are designed to work together flawlessly, and are balanced for usage in a survival setting. Pick and choose your favorites from our [website](https://gm4.co), or wherever you get datapacks.
